pywr.parameters.Parameter
=========================

.. currentmodule:: pywr.parameters

.. autoclass:: Parameter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Parameter.after
      ~Parameter.before
      ~Parameter.finish
      ~Parameter.get_all_values
      ~Parameter.get_double_lower_bounds
      ~Parameter.get_double_upper_bounds
      ~Parameter.get_double_variables
      ~Parameter.get_integer_lower_bounds
      ~Parameter.get_integer_upper_bounds
      ~Parameter.get_integer_variables
      ~Parameter.get_value
      ~Parameter.load
      ~Parameter.lower_bounds
      ~Parameter.register
      ~Parameter.reset
      ~Parameter.set_double_variables
      ~Parameter.set_integer_variables
      ~Parameter.setup
      ~Parameter.unregister
      ~Parameter.update
      ~Parameter.upper_bounds
      ~Parameter.value
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Parameter.children
      ~Parameter.comment
      ~Parameter.double_size
      ~Parameter.integer_size
      ~Parameter.is_variable
      ~Parameter.model
      ~Parameter.name
      ~Parameter.parents
      ~Parameter.size
   
   